# nicescad
nicescad brings OpenScad to the browser (again)

[![Join the discussion at https://github.com/WolfgangFahl/nicescad/discussions](https://img.shields.io/github/discussions/WolfgangFahl/nicescad)](https://github.com/WolfgangFahl/nicescad/discussions) 
[![pypi](https://img.shields.io/pypi/pyversions/nicescad)](https://pypi.org/project/nicescad/)
[![Github Actions Build](https://github.com/WolfgangFahl/nicescad/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/nicescad/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/nicescad.svg)](https://pypi.python.org/pypi/nicescad/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/nicescad.svg)](https://github.com/WolfgangFahl/nicescad/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/nicescad.svg)](https://github.com/WolfgangFahl/nicescad/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/nicescad.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Demo 
[Demo](http://nicescad.bitplan.com/)

## Docs and Tutorials
[Wiki](https://wiki.bitplan.com/index.php/nicescad)

## Examples
* [Basics/logo](https://raw.githubusercontent.com/openscad/openscad/master/examples/Basics/logo.scad)
* [Intersection](https://raw.githubusercontent.com/WolfgangFahl/nicescad/main/examples/intersection.scad)

## Links
* https://openscad.org/
* https://nicegui.io
* https://ochafik.com/openscad2/
